@@ -16,7 +16,10 @@ def Env(args,apps,parser):
     if args.app:
         if args.app in apps:
             if args.set:
-                stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.set])} -a {args.app}")
+                if args.p:
+                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.set])} -a {args.app} -p -w")
+                else:
+                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.set])} -a {args.app}")
             else:
                 stream = os.popen(f"xovnoc env -a {args.app}")
                 envs = str(stream.read()).strip().split('\n')
@@ -32,28 +35,6 @@ def Env(args,apps,parser):
     else:
         print('Please specify the application name using --app / -a <application_name>')
 
-# def SetEnv(args,apps,parser):
-#     if args.app:
-#         if args.app in apps:
-#             option=''
-#             while option not in 'Y,y,N,n'.split(','):
-#                 option=str(input("Would you like pyconvox to promote the new release? (Y/N): ")).strip()
-#                 if option == 'Y' or option == 'y':
-#                     stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
-#                 elif option == 'N' or option == 'n':
-#                     stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
-#                 else:
-#                     print("Only Y or N accepted!")
-#             # print(args.app)
-#         else:
-#             print("Wrong Application Name!!..\nPlease provide application name from the below")
-#             for index,appname in enumerate(apps):
-#                 print(f"{index+1}. {appname}")
-#             print()
-#             parser.print_help()
-#     else:
-#         print('Please specify the application name using --app / -a <application_name>')
-
 
 def Scale(args,apps,parser):
     if args.app:
@@ -133,20 +114,37 @@ def RailsC(args,apps,parser):
     else:
         print('Please specify the application name using --app / -a <application_name>')
 
+def Bash(args,apps,parser):
+    if args.app:
+        if args.app in apps:
+            if args.service:
+                service=str(args.service)
+            else:
+                stream = os.popen(f"xovnoc scale -a {args.app} | grep -v SERVICE | grep -E 'web|rake' | awk '"+"{print $1}' | head -n 1")
+                service = str(stream.read()).strip()
+            print(service)
+            stream = os.system(f"xovnoc run {service} bash -a {args.app}")
+            # console = str(stream.read()).strip()
+            print(stream)
+        else:
+            print("Wrong Application Name!!..\nPlease provide application name from the below")
+            for index,appname in enumerate(apps):
+                print(f"{index+1}. {appname}")
+            print()
+            parser.print_help()
+    else:
+        print('Please specify the application name using --app / -a <application_name>')
 
 def main():
     parser = argparse.ArgumentParser(prog="pyconvox",description='pyconvox - a wrapper for the convox application')
     parser.add_argument("--version","-V",action="version",version=f"%(prog)s version {pyconvox.__version__}",
     )
     subparsers = parser.add_subparsers(help='Commands')
-    # parser_0 = subparsers.add_parser('envset', help='set env var')
-    # parser_0.add_argument('--app', '-a', help='application name')
-    # parser_0.add_argument('envvars', metavar='Key=Value', nargs='+',help='env var(s) Key1=Value1,Key2=Value2,...')
-    # parser_0.set_defaults(which='envset')
 
     parser_a = subparsers.add_parser('env', help='list/set env vars')
     parser_a.add_argument('set', metavar='set', nargs='*', help='set environment variables KEY=VALUE')
     parser_a.add_argument('--app', '-a', help='application name')
+    parser_a.add_argument('--promote', '-p', nargs='*', help='promote')
     parser_a.set_defaults(which='env')
 
     parser_b = subparsers.add_parser('railsconsole', help='run rails console')
@@ -155,6 +153,12 @@ def main():
     parser_b.set_defaults(which='railsconsole')
     parser_b.set_defaults(service='')
 
+    parser_b = subparsers.add_parser('bash', help='run bash')
+    parser_b.add_argument('--app', '-a', help='application name')
+    parser_b.add_argument('--service', '-s', help='Service name')
+    parser_b.set_defaults(which='bash')
+    parser_b.set_defaults(service='')
+
     parser_c = subparsers.add_parser('scale', help='scale of a application')
     parser_c.add_argument('--app', '-a', help='application name')
     parser_c.set_defaults(which='scale')
@@ -187,10 +191,10 @@ def main():
             Env(args,apps,parser)
         elif args.which == 'railsconsole':
             RailsC(args,apps,parser)
+        elif args.which == 'bash':
+            Bash(args,apps,parser)
         elif args.which == 'scale':
             Scale(args,apps,parser)
-        # elif args.which == 'envset':
-        #     SetEnv(args,apps,parser)
         elif args.which == 'logs':
             Logs(args,apps,parser)
         elif args.which == 'instances':
